# pylint: skip-file

specifications = {
    "rpi-ir": {
        "height": 1944,
        "width": 2592,
        "diagonal": 3240,
        "fov": {
            "diagonal": 80,
            "horizontal": 64,
            "vertical": 48,
        },
    },
    "rpi-noir": {
        "height": 1944,
        "width": 2592,
        "diagonal": 3240,
        "fov": {
            "horizontal": 62.2,
            "vertical": 48.8,
        },
    },
    "rpi-rgb": {
        "height": 1944,
        "width": 2592,
        "diagonal": 3240,
        "fov": {
            "horizontal": 62.2,
            "vertical": 48.8,
        },
    },
}
